Summary:	The official GitLab CI runner written in Go
Name:		gitlab-ci-multi-runner
Version:	1.10.0
Release:	1
License:	MIT
Group:		Development/Building
Source0:	https://gitlab.com/gitlab-org/gitlab-ci-multi-runner/repository/archive.tar.gz?ref=v%{version}&/%{name}-%{version}.tar.gz
# Source0-md5:	fb2034a3c976d0abc2ae1579df3adf93
Source3:	%{name}.init
Source4:	%{name}.sysconfig
Source5:	%{name}.service
Patch0:		nodim_gz.patch
Patch1:		branch-preserver.patch
URL:		https://gitlab.com/gitlab-org/gitlab-ci-multi-runner
BuildRequires:	git-core
BuildRequires:	golang >= 1.6
BuildRequires:	rpmbuild(macros) >= 1.647
Requires(post,preun):	/sbin/chkconfig
Requires(post,preun,postun):	systemd-units >= 38
Requires(postun):	/usr/sbin/groupdel
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires(pre):	/usr/sbin/useradd
Requires:	bash
Requires:	ca-certificates
Requires:	git-core
Requires:	rc-scripts
Requires:	systemd-units >= 0.38
Requires:	tar
Suggests:	docker >= 1.8
Suggests:	gitlab-ci-multi-runner-image-arm
Suggests:	gitlab-ci-multi-runner-image-x86_64
Provides:	group(gitlab-runner)
Provides:	user(gitlab-runner)
ExclusiveArch:	%{ix86} %{x8664} %{arm}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# go stuff
%define _enable_debug_packages 0
%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%define import_path	gitlab.com/gitlab-org/gitlab-ci-multi-runner

%description
This is the official GitLab Runner written in Go. It runs tests and
sends the results to GitLab. GitLab CI is the open-source continuous
integration service included with GitLab that coordinates the testing.

%prep
%setup -qc

# for doc
mv gitlab-ci-multi-runner-*/*.md .

# don't you love go?
install -d src/$(dirname %{import_path})
mv gitlab-ci-multi-runner-* src/%{import_path}
cd src/%{import_path}

%patch0 -p1
%patch1 -p1

# avoid docker being used even if executable found
cat <<'EOF' > docker
#!/bin/sh
echo >&2 "No docker"
exit 1
EOF
chmod a+rx docker

%build
export GOPATH=$(pwd)
cd src/%{import_path}
export PATH=$(pwd):$PATH

%{__make} version | tee version.txt

CN=gitlab.com/gitlab-org/gitlab-ci-multi-runner/common
LDFLAGS="-X $CN.NAME=gitlab-ci-multi-runner -X $CN.VERSION=%{version} -X $CN.REVISION=%{version}"
%gobuild

# verify that version matches
./gitlab-ci-multi-runner -v > v
v=$(awk '$1 == "Version:" {print $2}' v)
test "$v" = "%{version}"

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_sysconfdir}/gitlab-runner,%{_bindir},/etc/{rc.d/init.d,sysconfig},%{systemdunitdir},/var/lib/gitlab-runner/.gitlab-runner}

install -p src/%{import_path}/%{name} $RPM_BUILD_ROOT%{_bindir}/gitlab-runner
install -p %{SOURCE3} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}
cp -p %{SOURCE4} $RPM_BUILD_ROOT/etc/sysconfig/%{name}
cp -p %{SOURCE5} $RPM_BUILD_ROOT%{systemdunitdir}

# backward compat name for previous pld packaging
ln -s gitlab-runner $RPM_BUILD_ROOT%{_bindir}/gitlab-ci-multi-runner

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%groupadd -g 330 gitlab-runner
%useradd -u 330 -d /var/lib/gitlab-runner -g gitlab-runner -c "GitLab Runner" gitlab-runner

%postun
if [ "$1" = "0" ]; then
	%userremove gitlab-runner
	%groupremove gitlab-runner
fi
%systemd_reload

%post
/sbin/chkconfig --add %{name}
%service %{name} restart
%systemd_post %{name}.service

%preun
if [ "$1" = "0" ]; then
	%service -q %{name} stop
	/sbin/chkconfig --del %{name}
fi
%systemd_preun %{name}.service

%files
%defattr(644,root,root,755)
%doc README.md CHANGELOG.md
%config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/gitlab-ci-multi-runner
%attr(754,root,root) /etc/rc.d/init.d/gitlab-ci-multi-runner
%dir %attr(750,root,root) %{_sysconfdir}/gitlab-runner
%attr(755,root,root) %{_bindir}/gitlab-ci-multi-runner
%attr(755,root,root) %{_bindir}/gitlab-runner
%{systemdunitdir}/gitlab-ci-multi-runner.service
%dir %attr(750,gitlab-runner,gitlab-runner) /var/lib/gitlab-runner
%dir %attr(750,gitlab-runner,gitlab-runner) /var/lib/gitlab-runner/.gitlab-runner
%changelog
* Mon Jan 23 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/gitlab-ci-multi-runner.git;a=log;h=master

* Mon Jan 23 2017 Elan Ruusamäe <glen@delfi.ee> 433251b
- up to 1.10.0

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> c543cc8
- up to 1.9.1

* Fri Dec 23 2016 Elan Ruusamäe <glen@delfi.ee> 225ac42
- up to 1.9.0

* Wed Dec 21 2016 Elan Ruusamäe <glen@delfi.ee> fbc2ca7
- up to 1.9.0-rc.4

* Thu Nov 24 2016 Elan Ruusamäe <glen@delfi.ee> b5ede9e
- version the build image as package version

* Thu Nov 24 2016 Elan Ruusamäe <glen@delfi.ee> 5d178ba
- up to 1.8.0; prebuilt docker images moved to separate package

* Mon Nov 14 2016 Elan Ruusamäe <glen@delfi.ee> b319407
- does not require curl

* Mon Nov 14 2016 Elan Ruusamäe <glen@delfi.ee> dfe9a17
- branch preserver: keep previous behavior for tags

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 2635dba
- rel 2; added initscripts

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 89c5c17
- misc sysv fixes

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> ea381f6
- use gitlab-runner as daemon process

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 451f15d
- pld start-stop-daemon has no --no-close option

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 4bd75c4
- fix status

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 50a6996
- pldize sysv initscript

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> 98c01f8
- initscript integration

* Fri Nov 04 2016 Elan Ruusamäe <glen@delfi.ee> af21cb3
- add initscripts from upstream repo

* Tue Oct 25 2016 Elan Ruusamäe <glen@delfi.ee> 636bc11
- up to 1.7.1

* Mon Oct 24 2016 Elan Ruusamäe <glen@delfi.ee> b42fabf
- up to 1.7.0

* Mon Oct 24 2016 Elan Ruusamäe <glen@delfi.ee> 1f4a44a
- use single checkout command

* Mon Oct 24 2016 Elan Ruusamäe <glen@delfi.ee> c4affa2
- patch to git reset --hard instead of checkout

